==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetSourceControlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetSourceControlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sourceControlId Source control Id
 * @property workspaceName The name of the workspace.
 */
public data class GetSourceControlPlainArgs(
    public val resourceGroupName: String,
    public val sourceControlId: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetSourceControlPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetSourceControlPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetSourceControlPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .sourceControlId(sourceControlId.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSourceControlPlainArgs].
 */
@PulumiTagMarker
public class GetSourceControlPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var sourceControlId: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("asvjsvkrpjgtcuit")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Source control Id
     */
    @JvmName("ekelipacyvcspsfv")
    public suspend fun sourceControlId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sourceControlId = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("bmtthhpculoammyx")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetSourceControlPlainArgs = GetSourceControlPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        sourceControlId = sourceControlId ?: throw PulumiNullFieldException("sourceControlId"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetSourceControlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetSourceControlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sourceControlId Source control Id
 * @property workspaceName The name of the workspace.
 */
public data class GetSourceControlPlainArgs(
    public val resourceGroupName: String,
    public val sourceControlId: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetSourceControlPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetSourceControlPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetSourceControlPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .sourceControlId(sourceControlId.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSourceControlPlainArgs].
 */
@PulumiTagMarker
public class GetSourceControlPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var sourceControlId: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("cgpbksyxtgteimvk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Source control Id
     */
    @JvmName("okkgvvicdehatyky")
    public suspend fun sourceControlId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sourceControlId = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("wsxwhladljkaovwb")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetSourceControlPlainArgs = GetSourceControlPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        sourceControlId = sourceControlId ?: throw PulumiNullFieldException("sourceControlId"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}
